<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>ComDialog</name>
    <message>
        <source>INFO</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>Connected to </source>
        <translation>Conectado a</translation>
    </message>
    <message>
        <source>Connecting to </source>
        <translation>Conectando con</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Desconectado</translation>
    </message>
    <message>
        <source>Qtel Error</source>
        <translation>Error en Qtel</translation>
    </message>
    <message>
        <source>Station data not found in directory server.
Can&apos;t create connection to</source>
        <translation>Datos de estación no encontrados en el servidor de directorio de Echolink. 
No se puede crear una conexión</translation>
    </message>
    <message>
        <source>Could not create connection to remote host</source>
        <translation>No se puede crear conexión con el host</translation>
    </message>
    <message>
        <source>Could not open mic audio device</source>
        <translation>No se puede abril el dispositovo de micrófono</translation>
    </message>
    <message>
        <source>Could not open speaker audio device</source>
        <translation>No se puede abril el dispositivo de salida de audio</translation>
    </message>
    <message>
        <source>Could not create connection to</source>
        <translation>No se puede crear una conexion con</translation>
    </message>
</context>
<context>
    <name>ComDialogBase</name>
    <message>
        <source>Communication Dialog</source>
        <translation>Diálogo de comunicación</translation>
    </message>
    <message>
        <source>Station Information</source>
        <translation>Información de la Estación</translation>
    </message>
    <message>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descripción:</translation>
    </message>
    <message>
        <source>IP-address:</source>
        <translation>Dirección-IP:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Estado:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translatorcomment>May be &quot;Hora&quot; which is te time of day, while &quot;Tiempo&quot; is about a period of time.</translatorcomment>
        <translation>Tiempo:</translation>
    </message>
    <message>
        <source>PTT</source>
        <translation>PTT</translation>
    </message>
    <message>
        <source>Chat/Info</source>
        <translation>Chat/Información</translation>
    </message>
    <message>
        <source>&amp;Connect</source>
        <translation>&amp;Conectar</translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation>&amp;Desconectar</translation>
    </message>
    <message>
        <source>RX</source>
        <translation>RX</translation>
    </message>
    <message>
        <source>TX</source>
        <translation>TX</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <source>Alt+D</source>
        <translation>Alt+D</translation>
    </message>
    <message>
        <source>VOX</source>
        <translation>VOX</translation>
    </message>
    <message>
        <source>VOX Enabled</source>
        <translation>VOX activado</translation>
    </message>
    <message>
        <source>Threshold:</source>
        <translation>Umbral:</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Retardo:</translation>
    </message>
    <message>
        <source>dB Level:</source>
        <translation>Nivel en dB:</translation>
    </message>
</context>
<context>
    <name>EchoLinkDirectoryModel</name>
    <message>
        <source>Callsign</source>
        <translatorcomment>May be translated as &quot;Señal distintiva&quot;.</translatorcomment>
        <translation>Señal de llamada</translation>
    </message>
    <message>
        <source>Location/Description</source>
        <translation>Ubicación/Descripción</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Local Time</source>
        <translation>Hora local</translation>
    </message>
    <message>
        <source>Node ID</source>
        <translation>ID del nodo</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Dirección IP</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Logging off from directory server...</source>
        <translation>Cerrando sesión con el servidor de directorio...</translation>
    </message>
    <message>
        <source>Station list has been refreshed</source>
        <translation>Se ha actualizado la lista de estaciones</translation>
    </message>
    <message>
        <source>Refreshing station list...</source>
        <translation>Actualizando lista de estaciones...</translation>
    </message>
    <message>
        <source>Qtel - Add station...</source>
        <translation>Qtel - Agregar estación...</translation>
    </message>
    <message>
        <source>Enter callsign of the station to add</source>
        <translation>Ingrese la señal de llamada de la estación a agregar</translation>
    </message>
    <message>
        <source>Qtel: Connect to IP</source>
        <translation>Qtel: Conectar a IP</translation>
    </message>
    <message>
        <source>Enter an IP address or hostname:</source>
        <translation>Ingrese dirección IP o nombre del equipo:</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Marcadores</translation>
    </message>
    <message>
        <source>Links</source>
        <translation>Enlaces</translation>
    </message>
    <message>
        <source>Repeaters</source>
        <translation>Repetidores</translation>
    </message>
    <message>
        <source>Conferences</source>
        <translation>Conferencias</translation>
    </message>
    <message>
        <source>Stations</source>
        <translation>Estaciones</translation>
    </message>
    <message>
        <source>About Qtel</source>
        <translation>Acerca de Qtel</translation>
    </message>
    <message>
        <source>Qtel v</source>
        <translation>Qtel v</translation>
    </message>
    <message>
        <source> - Qt EchoLink client.
</source>
        <translation>- Cliente EchoLink de Qt.</translation>
    </message>
    <message>
        <source>Copyright (C) 2011 Tobias Blomberg / SM0SVX

Qtel comes with ABSOLUTELY NO WARRANTY. This is free software, and you are welcome to redistribute it in accordance with the terms and conditions in the GNU GPL (General Public License) version 2 or later.</source>
        <translation>Copyright (C) 2011 Tobias Blomberg / SM0SVX
Qtel se ofrece con ABSOLUTAMENTE NINGUNA GARANTIA.  Este es software libre y se promueve su redistribucion de acuerdo con los terminos y condiciones expresados en la licencia GNU GPL (General Public License) version 2 o posterior.</translation>
    </message>
</context>
<context>
    <name>MainWindowBase</name>
    <message>
        <source>Conferences</source>
        <translation>Conferencias</translation>
    </message>
    <message>
        <source>Links</source>
        <translation>Enlaces</translation>
    </message>
    <message>
        <source>Repeaters</source>
        <translation>Repetidores</translation>
    </message>
    <message>
        <source>Stations</source>
        <translation>Estaciones</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Marcadores</translation>
    </message>
    <message>
        <source>Time</source>
        <translatorcomment>May be transtated as &quot;Tiempo&quot; which is related to a period of time.</translatorcomment>
        <translation>Hora</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>&amp;About...</source>
        <translation>&amp;Acerca de...</translation>
    </message>
    <message>
        <source>About Qtel</source>
        <translation>Acerca de Qtel</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>Quit the Qtel application</source>
        <translation>Finalizar la aplicación Qtel</translation>
    </message>
    <message>
        <source>Qtel Settings...</source>
        <translation>Ajustes de Qtel...</translation>
    </message>
    <message>
        <source>Open the Qtel settings dialog</source>
        <translation>Abrir configuración de Qtel</translation>
    </message>
    <message>
        <source>&amp;Directory</source>
        <translation>&amp;Directorio</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <source>&amp;Refresh</source>
        <translation>Ac&amp;tualizar</translation>
    </message>
    <message>
        <source>Refresh station list</source>
        <translation>Actualizar lista de estaciones</translation>
    </message>
    <message>
        <source>Qtel - the Qt EchoLink Client</source>
        <translation>Qtel - el cliente EchoLink de Qt</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Ocupado</translation>
    </message>
    <message>
        <source>&amp;Busy</source>
        <translation>&amp;Ocupado</translation>
    </message>
    <message>
        <source>View as busy</source>
        <translation>Visualizar como ocupado</translation>
    </message>
    <message>
        <source>View as busy in directory server</source>
        <translation>Visualizar como ocupado en servidor de directorio</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>Mensajes</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Callsign</source>
        <translation>Señal de llamada</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Connect to IP...</source>
        <translation>Conectar con dirección IP...</translation>
    </message>
    <message>
        <source>Connect to selected...</source>
        <translation>Conectar con estación seleccionada...</translation>
    </message>
    <message>
        <source>Incoming Connections</source>
        <translation>Conexiones entrantes</translation>
    </message>
    <message>
        <source>&amp;Station</source>
        <translation>E&amp;stación</translation>
    </message>
    <message>
        <source>S&amp;ettings</source>
        <translation>Ajust&amp;es</translation>
    </message>
    <message>
        <source>Connect to &amp;selected...</source>
        <translation>Conectar con &amp;seleccionado...</translation>
    </message>
    <message>
        <source>Connect to &amp;IP...</source>
        <translation>Conectar con &amp;IP...</translation>
    </message>
    <message>
        <source>Qtel &amp;Settings...</source>
        <translation>Aju&amp;stes de Qtel...</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>Add Selected To &amp;Bookmarks</source>
        <translation>Agregar seleccionados a Marcadores &amp;b</translation>
    </message>
    <message>
        <source>Add the selected station in the station list to the bookmarks menu</source>
        <translation>Agregal la estación seleccionada en la lista al menu de marcadores</translation>
    </message>
    <message>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <source>&amp;Remove Selected From Bookmarks</source>
        <translation>Elimina&amp;r Seleccionado de Marcadores</translation>
    </message>
    <message>
        <source>Remove the selected station from the bookmarks list</source>
        <translation>Eliminar la estación seleccionada de la lista de marcadores</translation>
    </message>
    <message>
        <source>Add &amp;Named Station To Bookmarks</source>
        <translation>Agregar Estación por &amp;Nombre a Marcadores</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Connect to the selected station</source>
        <translation>Conectar con la estacion seleccionada</translation>
    </message>
    <message>
        <source>Connect to local station using IP address or hostname</source>
        <translation>Conectar con una estación local utilizando IP o nombre del host</translation>
    </message>
    <message>
        <source>Immediately refresh the station list</source>
        <translation>Actualizar inmediatamente la lista de estaciones</translation>
    </message>
    <message>
        <source>Add selected station to the bookmarks</source>
        <translation>Agragar la estación seleccionada a marcadores</translation>
    </message>
    <message>
        <source>Remove the selected station from the bookmarks</source>
        <translation>Eliminar la estación seleccionada de marcadores</translation>
    </message>
    <message>
        <source>Add a station to the bookmarks by entering a callsign</source>
        <translation>Agregar una estación a marcadores ingresando la señal de llamada</translation>
    </message>
    <message>
        <source>Show the about dialog</source>
        <translation>Mostrar el dialogo Acerca de</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Qtel: Settings</source>
        <translation>Qtel: Ajustes</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>User Info</source>
        <translation>Información de usuario</translation>
    </message>
    <message>
        <source>User Information</source>
        <translation>Información de usuario</translation>
    </message>
    <message>
        <source>Info
Message</source>
        <translation>Mensaje de información</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Ubicación</translation>
    </message>
    <message>
        <source>Callsign</source>
        <translation>Señal de llamada</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <source>Retype password</source>
        <translation>Ingresar nuevamente la contraseña</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Directory Server Settings</source>
        <translation>Configuración del servidor de directorio</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Servidor</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Refresh time</source>
        <translation>Tiempo de actualización</translation>
    </message>
    <message>
        <source>min</source>
        <translation>min</translation>
    </message>
    <message>
        <source>Time, in minutes, between station list refreshes</source>
        <translation>Intervalo de minutos entre actualizaciones de la lista de estaciones</translation>
    </message>
    <message>
        <source>Register as busy on program startup</source>
        <translation>Iniciar programa en estado de ocupado</translation>
    </message>
    <message>
        <source>Start as busy</source>
        <translation>Iniciar como Ocupado</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Sonido</translation>
    </message>
    <message>
        <source>Full duplex</source>
        <translation>Full-duplex</translation>
    </message>
    <message>
        <source>Check this check box to enable full duplex operation</source>
        <translation>Marque esta casilla de verificación para permitir operación full-duplex</translation>
    </message>
    <message>
        <source>Connect Sound</source>
        <translation>Sonido de conexión</translation>
    </message>
    <message>
        <source>The connect sound to use on incoming EchoLink connections</source>
        <translation>El sonido utilizado para indicar una conexión entrante de EchoLink</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Buscar...</translation>
    </message>
    <message>
        <source>Raw Sound Files (*.raw)</source>
        <translation>Archivos Raw (*.raw)</translation>
    </message>
    <message>
        <source>Choose a connect sound file</source>
        <translation>Seleccione un archivo de sonido</translation>
    </message>
    <message>
        <source>QSO</source>
        <translation>QSO</translation>
    </message>
    <message>
        <source>Chat encoding:</source>
        <translation>Codificacion de chat:</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Chino</translation>
    </message>
    <message>
        <source>Japanese</source>
        <translation>Japonés</translation>
    </message>
    <message>
        <source>Korean</source>
        <translation>Coreano</translation>
    </message>
    <message>
        <source>Tamil</source>
        <translation>Tamil</translation>
    </message>
    <message>
        <source>Unicode, 8-bit</source>
        <translation>Unicode, 8-bit</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Ruso</translation>
    </message>
    <message>
        <source>Ukrainian</source>
        <translation>Ucraniano</translation>
    </message>
    <message>
        <source>Western</source>
        <translation>Occidental</translation>
    </message>
    <message>
        <source>Central European</source>
        <translation>Europa Central</translation>
    </message>
    <message>
        <source>Baltic</source>
        <translation>Báltico</translation>
    </message>
    <message>
        <source>Cyrillic</source>
        <translation>Cirílico</translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation>Árabe</translation>
    </message>
    <message>
        <source>Greek</source>
        <translation>Griego</translation>
    </message>
    <message>
        <source>Hebrew, visually ordered</source>
        <translation>Hebreo, arreglado visual</translation>
    </message>
    <message>
        <source>Hebrew, logically ordered</source>
        <translation>Hebreo, arreglado lógico </translation>
    </message>
    <message>
        <source>Turkish</source>
        <translation>Turco</translation>
    </message>
    <message>
        <source>Hebrew</source>
        <translation>Hebreo</translation>
    </message>
    <message>
        <source>Thai</source>
        <translation>Tailandés</translation>
    </message>
    <message>
        <source>Qtel: Password mismatch</source>
        <translation>Qtel: Contraseña incorrecta</translation>
    </message>
    <message>
        <source>Passwords do not match</source>
        <translation>Las contraseñas no concuerdan</translation>
    </message>
    <message>
        <source>Sound Settings</source>
        <translation>Ajustes de Sonido</translation>
    </message>
    <message>
        <source>Mic audio device</source>
        <translation>Dispositivo de microfono</translation>
    </message>
    <message>
        <source>The audio device to use (e.g. alsa:default)</source>
        <translation>El dispositivo de audio a utilizar (ej. alsa:default)</translation>
    </message>
    <message>
        <source>Speaker audio device</source>
        <translation>Dispositivo de salida de audio</translation>
    </message>
    <message>
        <source>QSO Dialog Settings</source>
        <translation>Ajustes del Diálogo QSO</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Red</translation>
    </message>
    <message>
        <source>Servers</source>
        <translation>Servidores</translation>
    </message>
    <message>
        <source>A space separated list of the hostname or IP address of the EchoLink directory servers to use</source>
        <translation>Una lista separada por estacios de nombres o direcciones IP de servidores de directorio de Echolink a utilizar</translation>
    </message>
    <message>
        <source>EchoLink Proxy Settings</source>
        <translation>Ajustes de Echolink Proxy</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Habilitar</translation>
    </message>
    <message>
        <source>If enabling EchoLink proxy you must supply a proxy server hostname or IP address.</source>
        <translation>Si se habilita un proxy de Echolink se debe suministrar el nombre o direccion IP del mismo.</translation>
    </message>
    <message>
        <source>The hostname or IP address of the EchoLink proxy server to use</source>
        <translation>El nombre o direccion IP del servidor proxy de Echolink a utilizar</translation>
    </message>
    <message>
        <source>TCP Port</source>
        <translation>Puerto TCP</translation>
    </message>
    <message>
        <source>The TCP port to connect to on the EchoLink proxy server, default 8100</source>
        <translation>El puerto TCP de conexion del proxy de Echolink, por defecto 8100</translation>
    </message>
    <message>
        <source>The EchoLink PROXY password, not your normal EchoLink password. Leave empty for public proxy.</source>
        <translation>El password del proxy Echolink, no el password normal de usuario.  Dejar vacio para proxy publicos.</translation>
    </message>
    <message>
        <source>Sampling Rate</source>
        <translation>Tasa de muestreo</translation>
    </message>
    <message>
        <source>EchoLink proxy configuration problem</source>
        <translation>Problema en la configuracion del proxy Echolink</translation>
    </message>
    <message>
        <source>EchoLink proxy enabled but no server given</source>
        <translation>Proxy Echolink habilitado pero no se especifica el servidor</translation>
    </message>
    <message>
        <source>Bind address</source>
        <translatorcomment>Maybe the word &quot;escucha&quot; is more related to &quot;listen address&quot;. Couldn&apos;t find a closer translation.</translatorcomment>
        <translation>Direccion de escucha</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;A bind address can be specified to force Qtel to use a specific network interface if your computer has more than one. Specify the IP address of the interface to bind to.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Se puede especificar una direccion para forzar a Qtel a utilizar una interfaz de red determinada si la PC posee mas de una. Especificar la direccion IP de la interfaz de red a utilizar.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
</context>
</TS>
